@@ -19,6 +19,8 @@ from .plot.reactions import (
 )
 from .model.friends import Friends
 from .plot.friends import plotMonthlyFriendsCreated
+from .model.comments import Comments
+from .plot.comments import plotTopXPeersWithMostCommentedPostsByUser
 from time import time
 
 
@@ -40,7 +42,7 @@ def _getBanner():
     '''
         Prints banner of scipt
     '''
-    print('\x1b[1;6;36;49m[+]fviz v0.5.0 - Facebook data visualizer\x1b[0m\n\n\t\x1b[3;30;47m$ fviz `path-to-exported-facebook-data.zip` `path-for-zip-extraction`  `path-to-sink-directory`\x1b[0m\n\n[+]Author: Anjan Roy < anjanroy@yandex.com >\n[+]Source: https://github.com/itzmeanjan/fviz ( MIT Licensed )\n')
+    print('\x1b[1;6;36;49m[+]fviz v0.6.0 - Facebook data visualizer\x1b[0m\n\n\t\x1b[3;30;47m$ fviz `path-to-exported-facebook-data.zip` `path-for-zip-extraction`  `path-to-sink-directory`\x1b[0m\n\n[+]Author: Anjan Roy < anjanroy@yandex.com >\n[+]Source: https://github.com/itzmeanjan/fviz ( MIT Licensed )\n')
 
 
 def _getCMD() -> Tuple[str, str, str]:
@@ -96,6 +98,15 @@ def main():
         if not friends:
             raise Exception('Failed to parse friends data')
 
+        comments = Comments.fromJSON(
+            join(extractAt,
+                 'comments/comments.json'
+                 )
+        )
+
+        if not comments:
+            raise Exception('Failed to parse comments data')
+
         _success = [
             plotReactionCount(
                 reactions.reactionTypeToCount,
@@ -163,6 +174,16 @@ def main():
                     'monthlyFriendingRateOf{}.svg'.format(
                         _splitAndJoinActorName(
                             reactions.reactions[0].actor)
+                    ))),
+            plotTopXPeersWithMostCommentedPostsByUser(
+                comments,
+                'Top 10 Facebook Profiles, with whom {} mostly interacted in Facebook Comments'.format(
+                    reactions.reactions[0].actor),
+                join(
+                    sink,
+                    'top10ProfilesWithMostlyCommentedPostsBy{}.svg'.format(
+                        _splitAndJoinActorName(
+                            reactions.reactions[0].actor)
                     )))
         ]
         print('[+]Completed in {} s with {}% success'.format(
